==> roadmapper-0.2.2.tar.gz: roadmapper-0.2.2/README.md <==
![Banner](https://github.com/csgoh/roadmapper/blob/main/images/roadmapper.jpg?raw=true)

[![license](https://img.shields.io/badge/license-mit-brightgreen.svg?style=plastic)](https://en.wikipedia.org/wiki/MIT_License)
![release](https://img.shields.io/pypi/v/roadmapper)
![Wheel](https://img.shields.io/pypi/wheel/roadmapper?style=plastic)
![download count](https://img.shields.io/pypi/dm/roadmapper?style=plastic)
![code size](https://img.shields.io/github/languages/code-size/csgoh/roadmapper?style=plastic)
![commit count](https://img.shields.io/github/commit-activity/m/csgoh/roadmapper?style=plastic)
![python version](https://img.shields.io/pypi/pyversions/roadmapper?style=plastic)

# Roadmaper - a Roadmap as Code (RaC) Tool

## Purpose
As the repo name implies, this purpose of this python library is used to draw roadmap by using python code. This is the first Roadmap as Code (RaC) library. RaC helps to create and edit roadmap in a more efficient way without having to use any graphical tools that are not always easy to use to create or update a roadmap.

With git repository like GitHub or Bitbucket, roadmaps created using RaC can be version controlled, track changes and can be easily shared with others.

### Latest version
**v.0.2.2**
### What's new in the latest version of Roadmapper?
* Replaced problematic pycairo with Pillow library
* Ability to add subtitle text
* Display vertical grey lines for timelines
* Display year on top of the timeline
* "Now" marker is updated to ▼
* Auto size surface height
* Fix defects

### Python version requirements:
* Python 3.10+
  
### Library Dependencies
* Pillow 9.3.0
* python-dateutil

## Future plans :bulb:
* Create roadmap with plain english text like PlantUML
* GUI and Web frontend for this roadmapper library
* Visual Studio Code extension to create and edit roadmap
<br/>

Any feedback or suggestions are welcome. Please feel free to create an issue or pull request.
<br/>
<br/>

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/csgoh)

<br/>
<hr>


## Installation
### Install from PyPI
```bash
pip install roadmapper
```
### Upgrade to the latest version
If you are running older version of roadmap-generator, you can upgrade to the latest version by running the following command:
```bash
pip install --upgrade roadmapper
```

<hr>

## Documentation
Please refer to [Roadmapper Wiki](https://github.com/csgoh/roadmap-generator/wiki) for more information on how to use this RaC library.

<br/>
<hr>

## Code Example

```python 
from roadmapper.roadmap import Roadmap
from roadmapper.timelinemode import TimelineMode

roadmap = Roadmap(1200, 312)
roadmap.set_title("My Demo Roadmap")
roadmap.set_timeline(TimelineMode.MONTHLY, "2023-02-01", 12)

group = roadmap.add_group("Core Product Work Stream")

task = group.add_task("Base Functionality", "2022-11-01", "2023-10-31")
task.add_milestone("v.1.0", "2023-02-15")
task.add_milestone("v.1.1", "2023-08-01")

parellel_task = task.add_parallel_task("Enhancements", "2023-11-15", "2024-03-31")
parellel_task.add_milestone("v.2.0", "2024-03-30")

task = group.add_task("Showcase #1", "2023-03-01", "2023-05-07")
task.add_parallel_task("Showcase #2", "2023-06-01", "2023-08-07")


roadmap.set_footer("Generated by Roadmap Generator")
roadmap.draw()
roadmap.save("demo01.png")
```

### Output

![Roadmapper](https://github.com/csgoh/roadmapper/blob/main/images/demo01.png?raw=true)

==> roadmapper-1.0.0.tar.gz: roadmapper-1.0.0/README.md <==
![Banner](https://github.com/csgoh/roadmapper/blob/main/images/roadmapper-banner.png?raw=true)

[![license](https://img.shields.io/badge/license-mit-brightgreen.svg?style=plastic)](https://en.wikipedia.org/wiki/MIT_License)
![release](https://img.shields.io/pypi/v/roadmapper)
![Wheel](https://img.shields.io/pypi/wheel/roadmapper?style=plastic)
![download count](https://img.shields.io/pypi/dm/roadmapper?style=plastic)
![code size](https://img.shields.io/github/languages/code-size/csgoh/roadmapper?style=plastic)
![commit count](https://img.shields.io/github/commit-activity/m/csgoh/roadmapper?style=plastic)
![python version](https://img.shields.io/pypi/pyversions/roadmapper?style=plastic)

# Roadmaper - a Roadmap as Code (RaC) Tool

## Purpose
The purpose of roadmapper python library is used to draw roadmap by using python code. This is the first Roadmap as Code (RaC) library. RaC helps to create and edit roadmap in a more efficient way without having to use any graphical tools that are not always easy to use to create or update a roadmap.

With git repository like GitHub or Bitbucket, roadmaps created using RaC can be version controlled, track changes and can be easily shared with others.

### Latest version
![release](https://img.shields.io/pypi/v/roadmapper)

### What's new in the latest version of Roadmapper?
* Provided options to show first day of week instead of W1, W2, etc. in WEEKLY timeline mode.
* Provided options to configure font and fill colour for year in the timeline section.
* Changed add_timeline() method parameters. font, font_size and font_colour are now deprecated. 
  *  To configure timeline year area, use year_font, year_font_size and year_fill_colour
  *  To configure timlien item area, use item_font, item_font_size and item_fill_colour
* Provided options to change task appearance in the roadmap. Task can now be displayed rectangular or rounded rectangle or rectangle with arrow head.
* Ability to add logo to the roadmap.
* Fix issue with WEEKLY timeline mode

### Python version requirements:
* Python 3.10+
  
### Library Dependencies
* Pillow 9.3.0
* python-dateutil

## Future plans :bulb:
* Create roadmap with plain english text like PlantUML
* GUI and Web frontend for this roadmapper library
* Visual Studio Code extension to create and edit roadmap
<br/>

Any feedback or suggestions are welcome. Please feel free to create an issue or pull request.
<br/>
<br/>
If you've been enjoying my contributions, consider buying me a coffee. It'll be like a virtual pat on the back for all the hard work. Thanks in advance! :coffee: :heart:

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/csgoh)

<br/>
<hr>


## Installation
### Install from PyPI
```bash
pip install roadmapper
```
### Upgrade to the latest version
If you are running older version of roadmap-generator, you can upgrade to the latest version by running the following command:
```bash
pip install --upgrade roadmapper
```

<hr>

## Documentation
Please refer to [Roadmapper Wiki](https://github.com/csgoh/roadmap-generator/wiki) for more information on how to use this RaC library.

<br/>
<hr>

## Code Example

```python 
from roadmapper.roadmap import Roadmap
from roadmapper.timelinemode import TimelineMode

roadmap = Roadmap(1200, 400, colour_theme="BLUEMOUNTAIN")
roadmap.set_title("My Demo Roadmap")
roadmap.set_timeline(TimelineMode.MONTHLY, "2023-01-01", 12)

group = roadmap.add_group("Core Product Work Stream")

task = group.add_task("Base Functionality", "2023-01-01", "2023-10-31")
task.add_milestone("v.1.0", "2023-02-15")
task.add_milestone("v.1.1", "2023-08-01")

parellel_task = task.add_parallel_task("Enhancements", "2023-11-15", "2024-03-31")
parellel_task.add_milestone("v.2.0", "2024-03-30")

task = group.add_task("Showcase #1", "2023-03-01", "2023-05-07")
task.add_parallel_task("Showcase #2", "2023-06-01", "2023-08-07")

roadmap.set_footer("Generated by Roadmapper")
roadmap.draw()
roadmap.save("demo01.png")
```

### Output

![Roadmapper](https://github.com/csgoh/roadmapper/blob/main/images/demo01.png?raw=true)
